==> rc-ui-lib-0.1.59.tgz: package/lib/collapse/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _testUtils() {
  var data = require("react-dom/test-utils");

  _testUtils = function _testUtils() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _cell = _interopRequireDefault(require("../../cell"));

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Collapse', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should update value when title is clicked', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              value: [],
              initValue: "1",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9"), /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98982",
              name: "2"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).at(0).children('.rc-collapse-item__title');
            _context.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(['first']);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should update value when title is clicked in accordion mode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              value: "",
              initValue: "1",
              accordion: true,
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9"), /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98982",
              name: "2"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).at(0).children('.rc-collapse-item__title');
            _context2.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('first');

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render CollapseItem correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      value: []
    }, /*#__PURE__*/React().createElement(_.default.Item, {
      title: "\u6807\u98981",
      name: "first",
      icon: "shop-o",
      value: "this is value",
      rightIcon: "question-o"
    }, "\u5185\u5BB9")));
    expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();
  });
  it('should not render border when border prop is false', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      border: false
    }));
    expect(wrapper.find('.rc-hairline--top-bottom').exists()).toBeFalsy();
  });
  it('should toggle collapse after calling the toggle method', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    var CollapseItemRef, onChange, toggle;
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            CollapseItemRef = /*#__PURE__*/React().createRef();
            onChange = jest.fn();

            toggle = function toggle(value) {
              CollapseItemRef.current.toggle(value);
            };

            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: [],
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              ref: CollapseItemRef
            }, "\u5185\u5BB9")));
            _context5.next = 6;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
              return _regenerator().default.wrap(function _callee3$(_context3) {
                while (1) {
                  switch (_context3.prev = _context3.next) {
                    case 0:
                      toggle(true);

                    case 1:
                    case "end":
                      return _context3.stop();
                  }
                }
              }, _callee3);
            })));

          case 6:
            expect(onChange).toHaveBeenCalledWith(['first']);
            _context5.next = 9;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
              return _regenerator().default.wrap(function _callee4$(_context4) {
                while (1) {
                  switch (_context4.prev = _context4.next) {
                    case 0:
                      toggle(false);

                    case 1:
                    case "end":
                      return _context4.stop();
                  }
                }
              }, _callee4);
            })));

          case 9:
            expect(onChange).toHaveBeenCalledWith([]);

          case 10:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should toggle collapse after calling the toggle method in accordion mode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    var CollapseItemRef, onChange, toggle;
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            CollapseItemRef = /*#__PURE__*/React().createRef();
            onChange = jest.fn();

            toggle = function toggle(value) {
              CollapseItemRef.current.toggle(value);
            };

            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              accordion: true,
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              ref: CollapseItemRef
            }, "\u5185\u5BB9")));
            _context8.next = 6;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
              return _regenerator().default.wrap(function _callee6$(_context6) {
                while (1) {
                  switch (_context6.prev = _context6.next) {
                    case 0:
                      toggle(true);

                    case 1:
                    case "end":
                      return _context6.stop();
                  }
                }
              }, _callee6);
            })));

          case 6:
            expect(onChange).toHaveBeenCalledWith('first');
            _context8.next = 9;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
              return _regenerator().default.wrap(function _callee7$(_context7) {
                while (1) {
                  switch (_context7.prev = _context7.next) {
                    case 0:
                      toggle(false);

                    case 1:
                    case "end":
                      return _context7.stop();
                  }
                }
              }, _callee7);
            })));

          case 9:
            expect(onChange).toHaveBeenCalledWith('');

          case 10:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should be readonly when using readonly prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              readonly: true
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            _context9.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).not.toHaveBeenCalled();
            expect(wrapper.find('i').exists()).toBeFalsy();

          case 7:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should be readonly when using disabled prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee10() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              disabled: true
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            _context10.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).not.toHaveBeenCalled();
            expect(wrapper.find('.rc-collapse-item__title--disabled').exists()).toBeTruthy();

          case 7:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('when value is change', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee11() {
    var title;
    return _regenerator().default.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              accordion: true,
              value: ""
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            title.simulate('click');
            _context11.next = 5;
            return wrapper.setProps({
              value: 'first'
            });

          case 5:
            expect(wrapper.props().value).toEqual('first');

          case 6:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/lib/collapse/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _testUtils() {
  var data = require("react-dom/test-utils");

  _testUtils = function _testUtils() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _cell = _interopRequireDefault(require("../../cell"));

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Collapse', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should update value when title is clicked', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              value: [],
              initValue: "1",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9"), /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98982",
              name: "2"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).at(0).children('.rc-collapse-item__title');
            _context.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith(['first']);

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should update value when title is clicked in accordion mode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              value: "",
              initValue: "1",
              accordion: true,
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9"), /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98982",
              name: "2"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).at(0).children('.rc-collapse-item__title');
            _context2.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).toHaveBeenCalledWith('first');

          case 6:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render CollapseItem correctly', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      value: []
    }, /*#__PURE__*/React().createElement(_.default.Item, {
      title: "\u6807\u98981",
      name: "first",
      icon: "shop-o",
      value: "this is value",
      rightIcon: "question-o"
    }, "\u5185\u5BB9")));
    expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();
  });
  it('should not render border when border prop is false', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
      border: false
    }));
    expect(wrapper.find('.rc-hairline--top-bottom').exists()).toBeFalsy();
  });
  it('should toggle collapse after calling the toggle method', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    var CollapseItemRef, onChange, toggle;
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            CollapseItemRef = /*#__PURE__*/React().createRef();
            onChange = jest.fn();

            toggle = function toggle(value) {
              CollapseItemRef.current.toggle(value);
            };

            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: [],
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              ref: CollapseItemRef
            }, "\u5185\u5BB9")));
            _context5.next = 6;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
              return _regenerator().default.wrap(function _callee3$(_context3) {
                while (1) {
                  switch (_context3.prev = _context3.next) {
                    case 0:
                      toggle(true);

                    case 1:
                    case "end":
                      return _context3.stop();
                  }
                }
              }, _callee3);
            })));

          case 6:
            expect(onChange).toHaveBeenCalledWith(['first']);
            _context5.next = 9;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
              return _regenerator().default.wrap(function _callee4$(_context4) {
                while (1) {
                  switch (_context4.prev = _context4.next) {
                    case 0:
                      toggle(false);

                    case 1:
                    case "end":
                      return _context4.stop();
                  }
                }
              }, _callee4);
            })));

          case 9:
            expect(onChange).toHaveBeenCalledWith([]);

          case 10:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should toggle collapse after calling the toggle method in accordion mode', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    var CollapseItemRef, onChange, toggle;
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            CollapseItemRef = /*#__PURE__*/React().createRef();
            onChange = jest.fn();

            toggle = function toggle(value) {
              CollapseItemRef.current.toggle(value);
            };

            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              accordion: true,
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              ref: CollapseItemRef
            }, "\u5185\u5BB9")));
            _context8.next = 6;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
              return _regenerator().default.wrap(function _callee6$(_context6) {
                while (1) {
                  switch (_context6.prev = _context6.next) {
                    case 0:
                      toggle(true);

                    case 1:
                    case "end":
                      return _context6.stop();
                  }
                }
              }, _callee6);
            })));

          case 6:
            expect(onChange).toHaveBeenCalledWith('first');
            _context8.next = 9;
            return (0, _testUtils().act)( /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
              return _regenerator().default.wrap(function _callee7$(_context7) {
                while (1) {
                  switch (_context7.prev = _context7.next) {
                    case 0:
                      toggle(false);

                    case 1:
                    case "end":
                      return _context7.stop();
                  }
                }
              }, _callee7);
            })));

          case 9:
            expect(onChange).toHaveBeenCalledWith('');

          case 10:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should be readonly when using readonly prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              readonly: true
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            _context9.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).not.toHaveBeenCalled();
            expect(wrapper.find('i').exists()).toBeFalsy();

          case 7:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should be readonly when using disabled prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee10() {
    var onChange, title;
    return _regenerator().default.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            onChange = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              onChange: onChange
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first",
              disabled: true
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            _context10.next = 5;
            return title.simulate('click');

          case 5:
            expect(onChange).not.toHaveBeenCalled();
            expect(wrapper.find('.rc-collapse-item__title--disabled').exists()).toBeTruthy();

          case 7:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('when value is change', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee11() {
    var title;
    return _regenerator().default.wrap(function _callee11$(_context11) {
      while (1) {
        switch (_context11.prev = _context11.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              initValue: "",
              accordion: true,
              value: ""
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              title: "\u6807\u98981",
              name: "first"
            }, "\u5185\u5BB9")));
            title = wrapper.find(_cell.default).children('.rc-collapse-item__title');
            title.simulate('click');
            _context11.next = 5;
            return wrapper.setProps({
              value: 'first'
            });

          case 5:
            expect(wrapper.props().value).toEqual('first');

          case 6:
          case "end":
            return _context11.stop();
        }
      }
    }, _callee11);
  })));
});
